@@ -43,7 +43,7 @@ def parse_to_python_object(string, from_CLI=True):
                 pos = values.find(')', pos+1)
                 el = values[:pos + 1]
                 
-            result_arr.append(parse_to_python_object_v2(el.strip()))
+            result_arr.append(parse_to_python_object(el.strip()))
             
             values = values[pos+1:]
             if values.startswith(','):
@@ -53,7 +53,7 @@ def parse_to_python_object(string, from_CLI=True):
         values = values.strip()
         
         if values != '':
-            result_arr.append(parse_to_python_object_v2(values))
+            result_arr.append(parse_to_python_object(values))
 
         return result_arr
     
@@ -77,7 +77,7 @@ def parse_to_python_object(string, from_CLI=True):
             k = el[:el.find('=')]
             v = el[el.find('=')+1:]
     
-            result_dict.update({k.strip().replace('"',''): parse_to_python_object_v2(v.strip())})
+            result_dict.update({k.strip().replace('"',''): parse_to_python_object(v.strip())})
             
             values = values[pos+1:]
             pos = values.find(';')
